==> paraview-5.10.1-9-x86_64.pkg.tar.zst: opt/paraview/include/paraview/vtkPVVTKExtensionsInteractionStyleModule.h <==

#ifndef VTKPVVTKEXTENSIONSINTERACTIONSTYLE_EXPORT_H
#define VTKPVVTKEXTENSIONSINTERACTIONSTYLE_EXPORT_H

#ifdef VTKPVVTKEXTENSIONSINTERACTIONSTYLE_STATIC_DEFINE
#  define VTKPVVTKEXTENSIONSINTERACTIONSTYLE_EXPORT
#  define VTKPVVTKEXTENSIONSINTERACTIONSTYLE_NO_EXPORT
#else
#  ifndef VTKPVVTKEXTENSIONSINTERACTIONSTYLE_EXPORT
#    ifdef VTKExtensionsInteractionStyle_EXPORTS
        /* We are building this library */
#      define VTKPVVTKEXTENSIONSINTERACTIONSTYLE_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define VTKPVVTKEXTENSIONSINTERACTIONSTYLE_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef VTKPVVTKEXTENSIONSINTERACTIONSTYLE_NO_EXPORT
#    define VTKPVVTKEXTENSIONSINTERACTIONSTYLE_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef VTKPVVTKEXTENSIONSINTERACTIONSTYLE_DEPRECATED
#  define VTKPVVTKEXTENSIONSINTERACTIONSTYLE_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef VTKPVVTKEXTENSIONSINTERACTIONSTYLE_DEPRECATED_EXPORT
#  define VTKPVVTKEXTENSIONSINTERACTIONSTYLE_DEPRECATED_EXPORT VTKPVVTKEXTENSIONSINTERACTIONSTYLE_EXPORT VTKPVVTKEXTENSIONSINTERACTIONSTYLE_DEPRECATED
#endif

#ifndef VTKPVVTKEXTENSIONSINTERACTIONSTYLE_DEPRECATED_NO_EXPORT
#  define VTKPVVTKEXTENSIONSINTERACTIONSTYLE_DEPRECATED_NO_EXPORT VTKPVVTKEXTENSIONSINTERACTIONSTYLE_NO_EXPORT VTKPVVTKEXTENSIONSINTERACTIONSTYLE_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef VTKPVVTKEXTENSIONSINTERACTIONSTYLE_NO_DEPRECATED
#    define VTKPVVTKEXTENSIONSINTERACTIONSTYLE_NO_DEPRECATED
#  endif
#endif

#endif /* VTKPVVTKEXTENSIONSINTERACTIONSTYLE_EXPORT_H */

==> paraview-5.12.1-4-x86_64.pkg.tar.zst: opt/paraview/include/paraview/vtkPVVTKExtensionsInteractionStyleModule.h <==

#ifndef VTKPVVTKEXTENSIONSINTERACTIONSTYLE_EXPORT_H
#define VTKPVVTKEXTENSIONSINTERACTIONSTYLE_EXPORT_H

#ifdef VTKPVVTKEXTENSIONSINTERACTIONSTYLE_STATIC_DEFINE
#  define VTKPVVTKEXTENSIONSINTERACTIONSTYLE_EXPORT
#  define VTKPVVTKEXTENSIONSINTERACTIONSTYLE_NO_EXPORT
#else
#  ifndef VTKPVVTKEXTENSIONSINTERACTIONSTYLE_EXPORT
#    ifdef VTKExtensionsInteractionStyle_EXPORTS
        /* We are building this library */
#      define VTKPVVTKEXTENSIONSINTERACTIONSTYLE_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define VTKPVVTKEXTENSIONSINTERACTIONSTYLE_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef VTKPVVTKEXTENSIONSINTERACTIONSTYLE_NO_EXPORT
#    define VTKPVVTKEXTENSIONSINTERACTIONSTYLE_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef VTKPVVTKEXTENSIONSINTERACTIONSTYLE_DEPRECATED
#  define VTKPVVTKEXTENSIONSINTERACTIONSTYLE_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef VTKPVVTKEXTENSIONSINTERACTIONSTYLE_DEPRECATED_EXPORT
#  define VTKPVVTKEXTENSIONSINTERACTIONSTYLE_DEPRECATED_EXPORT VTKPVVTKEXTENSIONSINTERACTIONSTYLE_EXPORT VTKPVVTKEXTENSIONSINTERACTIONSTYLE_DEPRECATED
#endif

#ifndef VTKPVVTKEXTENSIONSINTERACTIONSTYLE_DEPRECATED_NO_EXPORT
#  define VTKPVVTKEXTENSIONSINTERACTIONSTYLE_DEPRECATED_NO_EXPORT VTKPVVTKEXTENSIONSINTERACTIONSTYLE_NO_EXPORT VTKPVVTKEXTENSIONSINTERACTIONSTYLE_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef VTKPVVTKEXTENSIONSINTERACTIONSTYLE_NO_DEPRECATED
#    define VTKPVVTKEXTENSIONSINTERACTIONSTYLE_NO_DEPRECATED
#  endif
#endif

/* VTK-HeaderTest-Exclude: vtkPVVTKExtensionsInteractionStyleModule.h */

/* Include ABI Namespace */
#include "vtkABINamespace.h"

#endif /* VTKPVVTKEXTENSIONSINTERACTIONSTYLE_EXPORT_H */
